==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/TempPassword.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * TempPassword
 */
@JsonPropertyOrder({ TempPassword.JSON_PROPERTY_TEMP_PASSWORD })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class TempPassword implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TEMP_PASSWORD = "tempPassword";
    private String tempPassword;

    public TempPassword() {
    }

    /*
     * @JsonCreator public TempPassword(
     *
     * @JsonProperty(JSON_PROPERTY_TEMP_PASSWORD) String tempPassword ) { this(); this.tempPassword = tempPassword; }
     */

    /**
     * Get tempPassword
     *
     * @return tempPassword
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TEMP_PASSWORD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getTempPassword() {
        return tempPassword;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TempPassword tempPassword = (TempPassword) o;
        return Objects.equals(this.tempPassword, tempPassword.tempPassword);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(tempPassword);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TempPassword {\n");
        sb.append("    tempPassword: ").append(toIndentedString(tempPassword)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/TempPassword.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * TempPassword
 */
@JsonPropertyOrder({ TempPassword.JSON_PROPERTY_TEMP_PASSWORD })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class TempPassword implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TEMP_PASSWORD = "tempPassword";
    private String tempPassword;

    public TempPassword() {
    }

    /*
     * @JsonCreator public TempPassword(
     *
     * @JsonProperty(JSON_PROPERTY_TEMP_PASSWORD) String tempPassword ) { this(); this.tempPassword = tempPassword; }
     */

    /**
     * Get tempPassword
     *
     * @return tempPassword
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TEMP_PASSWORD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getTempPassword() {
        return tempPassword;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TempPassword tempPassword = (TempPassword) o;
        return Objects.equals(this.tempPassword, tempPassword.tempPassword);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(tempPassword);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TempPassword {\n");
        sb.append("    tempPassword: ").append(toIndentedString(tempPassword)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
